@@ -11,40 +11,45 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-import os
-import sys
-import mock
-import time
-import random
-import shutil
-import contextlib
-import tempfile
 import binascii
-import platform
-import select
+import contextlib
 import datetime
+import os
+import platform
+import random
+import select
+import shutil
+import sys
+import tempfile
+import time
+import unittest
+from contextlib import ContextDecorator
 from io import BytesIO
-from subprocess import Popen, PIPE
+from subprocess import PIPE, Popen
+from unittest import mock
 
 from dateutil.tz import tzlocal
-import unittest
-
-from nose.tools import assert_equal
 
 import botocore.loaders
 import botocore.session
+from botocore import credentials, utils
 from botocore.awsrequest import AWSResponse
-from botocore.compat import six
-from botocore.compat import urlparse
-from botocore.compat import parse_qs
-from botocore import utils
-from botocore import credentials
+from botocore.compat import HAS_CRT, parse_qs, urlparse
 from botocore.stub import Stubber
 
-
 _LOADER = botocore.loaders.Loader()
 
 
+def _all_services():
+    session = botocore.session.Session()
+    service_names = session.get_available_services()
+    return [session.get_service_model(name) for name in service_names]
+
+
+# Only compute our service models once
+ALL_SERVICES = _all_services()
+
+
 def skip_unless_has_memory_collection(cls):
     """Class decorator to skip tests that require memory collection.
 
@@ -65,9 +70,22 @@ def skip_if_windows(reason):
         def test_some_non_windows_stuff(self):
             self.assertEqual(...)
     """
+
     def decorator(func):
         return unittest.skipIf(
-            platform.system() not in ['Darwin', 'Linux'], reason)(func)
+            platform.system() not in ['Darwin', 'Linux'], reason
+        )(func)
+
+    return decorator
+
+
+def requires_crt(reason=None):
+    if reason is None:
+        reason = "Test requires awscrt to be installed"
+
+    def decorator(func):
+        return unittest.skipIf(not HAS_CRT, reason)(func)
+
     return decorator
 
 
@@ -103,7 +121,9 @@ def temporary_file(mode):
 
     """
     temporary_directory = tempfile.mkdtemp()
-    basename = 'tmpfile-%s-%s' % (int(time.time()), random.randint(1, 1000))
+    basename = 'tmpfile-{}-{}'.format(
+        int(time.time()), random.randint(1, 1000)
+    )
     full_filename = os.path.join(temporary_directory, basename)
     open(full_filename, 'w').close()
     try:
@@ -140,7 +160,7 @@ class BaseSessionTest(BaseEnvVar):
     """
 
     def setUp(self, **environ):
-        super(BaseSessionTest, self).setUp()
+        super().setUp()
         self.environ['AWS_ACCESS_KEY_ID'] = 'access_key'
         self.environ['AWS_SECRET_ACCESS_KEY'] = 'secret_key'
         self.environ['AWS_CONFIG_FILE'] = 'no-exist-foo'
@@ -157,8 +177,7 @@ class BaseClientDriverTest(unittest.TestCase):
         self.driver = ClientDriver()
         env = None
         if self.INJECT_DUMMY_CREDS:
-            env = {'AWS_ACCESS_KEY_ID': 'foo',
-                   'AWS_SECRET_ACCESS_KEY': 'bar'}
+            env = {'AWS_ACCESS_KEY_ID': 'foo', 'AWS_SECRET_ACCESS_KEY': 'bar'}
         self.driver.start(env=env)
 
     def cmd(self, *args):
@@ -178,10 +197,9 @@ class BaseClientDriverTest(unittest.TestCase):
         self.driver.stop()
 
 
-class ClientDriver(object):
+class ClientDriver:
     CLIENT_SERVER = os.path.join(
-        os.path.dirname(os.path.abspath(__file__)),
-        'cmd-runner'
+        os.path.dirname(os.path.abspath(__file__)), 'cmd-runner'
     )
 
     def __init__(self):
@@ -209,8 +227,12 @@ class ClientDriver(object):
 
     def start(self, env=None):
         """Start up the command runner process."""
-        self._popen = Popen([sys.executable, self.CLIENT_SERVER],
-                            stdout=PIPE, stdin=PIPE, env=env)
+        self._popen = Popen(
+            [sys.executable, self.CLIENT_SERVER],
+            stdout=PIPE,
+            stdin=PIPE,
+            env=env,
+        )
 
     def stop(self):
         """Shutdown the command runner process."""
@@ -259,8 +281,7 @@ class ClientDriver(object):
         self.send_cmd(*cmd)
         result = self._popen.stdout.readline().strip()
         if result != b'OK':
-            raise RuntimeError(
-                "Error from command '%s': %s" % (cmd, result))
+            raise RuntimeError(f"Error from command '{cmd}': {result}")
 
 
 # This is added to this file because it's used in both
@@ -286,18 +307,21 @@ class IntegerRefresher(credentials.RefreshableCredentials):
     _mandatory_refresh_timeout = 1
     _credentials_expire = 3
 
-    def __init__(self, creds_last_for=_credentials_expire,
-                 advisory_refresh=_advisory_refresh_timeout,
-                 mandatory_refresh=_mandatory_refresh_timeout,
-                 refresh_function=None):
-        expires_in = (
-            self._current_datetime() +
-            datetime.timedelta(seconds=creds_last_for))
+    def __init__(
+        self,
+        creds_last_for=_credentials_expire,
+        advisory_refresh=_advisory_refresh_timeout,
+        mandatory_refresh=_mandatory_refresh_timeout,
+        refresh_function=None,
+    ):
+        expires_in = self._current_datetime() + datetime.timedelta(
+            seconds=creds_last_for
+        )
         if refresh_function is None:
             refresh_function = self._do_refresh
-        super(IntegerRefresher, self).__init__(
-            '0', '0', '0', expires_in,
-            refresh_function, 'INTREFRESH')
+        super().__init__(
+            '0', '0', '0', expires_in, refresh_function, 'INTREFRESH'
+        )
         self.creds_last_for = creds_last_for
         self.refresh_counter = 0
         self._advisory_refresh_timeout = advisory_refresh
@@ -335,27 +359,28 @@ class IntegerRefresher(credentials.RefreshableCredentials):
 
 
 def _urlparse(url):
-    if isinstance(url, six.binary_type):
+    if isinstance(url, bytes):
         # Not really necessary, but it helps to reduce noise on Python 2.x
         url = url.decode('utf8')
     return urlparse(url)
 
+
 def assert_url_equal(url1, url2):
     parts1 = _urlparse(url1)
     parts2 = _urlparse(url2)
 
     # Because the query string ordering isn't relevant, we have to parse
     # every single part manually and then handle the query string.
-    assert_equal(parts1.scheme, parts2.scheme)
-    assert_equal(parts1.netloc, parts2.netloc)
-    assert_equal(parts1.path, parts2.path)
-    assert_equal(parts1.params, parts2.params)
-    assert_equal(parts1.fragment, parts2.fragment)
-    assert_equal(parts1.username, parts2.username)
-    assert_equal(parts1.password, parts2.password)
-    assert_equal(parts1.hostname, parts2.hostname)
-    assert_equal(parts1.port, parts2.port)
-    assert_equal(parse_qs(parts1.query), parse_qs(parts2.query))
+    assert parts1.scheme == parts2.scheme
+    assert parts1.netloc == parts2.netloc
+    assert parts1.path == parts2.path
+    assert parts1.params == parts2.params
+    assert parts1.fragment == parts2.fragment
+    assert parts1.username == parts2.username
+    assert parts1.password == parts2.password
+    assert parts1.hostname == parts2.hostname
+    assert parts1.port == parts2.port
+    assert parse_qs(parts1.query) == parse_qs(parts2.query)
 
 
 class HTTPStubberException(Exception):
@@ -372,7 +397,7 @@ class RawResponse(BytesIO):
             contents = self.read()
 
 
-class BaseHTTPStubber(object):
+class BaseHTTPStubber:
     def __init__(self, obj_with_event_emitter, strict=True):
         self.reset()
         self._strict = strict
@@ -382,8 +407,9 @@ class BaseHTTPStubber(object):
         self.requests = []
         self.responses = []
 
-    def add_response(self, url='https://example.com', status=200, headers=None,
-                     body=b''):
+    def add_response(
+        self, url='https://example.com', status=200, headers=None, body=b''
+    ):
         if headers is None:
             headers = {}
 
@@ -438,7 +464,7 @@ class ConsistencyWaiterException(Exception):
     pass
 
 
-class ConsistencyWaiter(object):
+class ConsistencyWaiter:
     """
     A waiter class for some check to reach a consistent state.
 
@@ -454,8 +480,14 @@ class ConsistencyWaiter(object):
     :param delay: The number of seconds to delay the next API call after a
     failed check call. Default of 5 seconds.
     """
-    def __init__(self, min_successes=1, max_attempts=20, delay=5,
-                 delay_initial_poll=False):
+
+    def __init__(
+        self,
+        min_successes=1,
+        max_attempts=20,
+        delay=5,
+        delay_initial_poll=False,
+    ):
         self.min_successes = min_successes
         self.max_attempts = max_attempts
         self.delay = delay
@@ -497,7 +529,7 @@ class ConsistencyWaiter(object):
 
 class StubbedSession(botocore.session.Session):
     def __init__(self, *args, **kwargs):
-        super(StubbedSession, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._cached_clients = {}
         self._client_stubs = {}
 
@@ -508,8 +540,7 @@ class StubbedSession(botocore.session.Session):
         return self._cached_clients[service_name]
 
     def _create_stubbed_client(self, service_name, *args, **kwargs):
-        client = super(StubbedSession, self).create_client(
-            service_name, *args, **kwargs)
+        client = super().create_client(service_name, *args, **kwargs)
         stubber = Stubber(client)
         self._client_stubs[service_name] = stubber
         return client
@@ -526,3 +557,44 @@ class StubbedSession(botocore.session.Session):
     def verify_stubs(self):
         for stub in self._client_stubs.values():
             stub.assert_no_pending_responses()
+
+
+class FreezeTime(ContextDecorator):
+    """
+    Context manager for mocking out datetime in arbitrary modules when creating
+    performing actions like signing which require point in time specificity.
+
+    :type module: module
+    :param module: reference to imported module to patch (e.g. botocore.auth.datetime)
+
+    :type date: datetime.datetime
+    :param date: datetime object specifying the output for utcnow()
+    """
+
+    def __init__(self, module, date=None):
+        if date is None:
+            date = datetime.datetime.utcnow()
+        self.date = date
+        self.datetime_patcher = mock.patch.object(
+            module, 'datetime', mock.Mock(wraps=datetime.datetime)
+        )
+
+    def __enter__(self, *args, **kwargs):
+        mock = self.datetime_patcher.start()
+        mock.utcnow.return_value = self.date
+
+    def __exit__(self, *args, **kwargs):
+        self.datetime_patcher.stop()
+
+
+def patch_load_service_model(
+    session, monkeypatch, service_model_json, ruleset_json
+):
+    def mock_load_service_model(service_name, type_name, api_version=None):
+        if type_name == 'service-2':
+            return service_model_json
+        if type_name == 'endpoint-rule-set-1':
+            return ruleset_json
+
+    loader = session.get_component('data_loader')
+    monkeypatch.setattr(loader, 'load_service_model', mock_load_service_model)
