@@ -33,15 +33,17 @@ def _shared_example_configs():
 
 
 @pytest.mark.parametrize(
-    "operation_name, example_config, service_model",
-    _shared_example_configs()
+    "operation_name, example_config, service_model", _shared_example_configs()
 )
-def test_lint_shared_example_configs(operation_name, example_config, service_model):
+def test_lint_shared_example_configs(
+    operation_name, example_config, service_model
+):
     # The operation should actually exist
     assert_operation_exists(service_model, operation_name)
     operation_model = service_model.operation_model(operation_name)
-    assert_valid_values(service_model.service_name, operation_model,
-                        example_config)
+    assert_valid_values(
+        service_model.service_name, operation_model, example_config
+    )
 
 
 def assert_valid_values(service_name, operation_model, example_config):
@@ -52,9 +54,9 @@ def assert_valid_values(service_name, operation_model, example_config):
     if input_shape is None and example_input:
         raise AssertionError(
             "Input found in example for %s from %s with id %s, but no input "
-            "shape is defined." % (
-                operation_model.name, service_name, example_id
-            ))
+            "shape is defined."
+            % (operation_model.name, service_name, example_id)
+        )
 
     example_output = example_config.get('output')
     output_shape = operation_model.output_shape
@@ -62,23 +64,26 @@ def assert_valid_values(service_name, operation_model, example_config):
     if output_shape is None and example_output:
         raise AssertionError(
             "Output found in example for %s from %s with id %s, but no output "
-            "shape is defined." % (
-                operation_model.name, service_name, example_id
-            ))
+            "shape is defined."
+            % (operation_model.name, service_name, example_id)
+        )
 
     try:
         if example_input is not None and input_shape is not None:
             _assert_valid_values(
-                input_shape, example_input, [input_shape.name])
+                input_shape, example_input, [input_shape.name]
+            )
 
         if example_output is not None and output_shape is not None:
             _assert_valid_values(
-                output_shape, example_output, [output_shape.name])
+                output_shape, example_output, [output_shape.name]
+            )
     except AssertionError as e:
         raise AssertionError(
-            "Invalid value in example for %s from %s with id %s: %s" % (
+            "Invalid value in example for {} from {} with id {}: {}".format(
                 operation_model.name, service_name, example_id, e
-            ))
+            )
+        )
 
 
 def _assert_valid_values(shape, example_value, path):
@@ -93,12 +98,15 @@ def _assert_valid_values(shape, example_value, path):
 
 
 def _assert_valid_structure_values(shape, example_dict, path):
-    invalid_members = [k for k in example_dict.keys()
-                       if k not in shape.members]
+    invalid_members = [
+        k for k in example_dict.keys() if k not in shape.members
+    ]
     if invalid_members:
         dotted_path = '.'.join(path)
         raise AssertionError(
-            "Invalid members found for %s: %s" % (dotted_path, invalid_members)
+            "Invalid members found for {}: {}".format(
+                dotted_path, invalid_members
+            )
         )
 
     for member_name, example_value in example_dict.items():
@@ -109,13 +117,13 @@ def _assert_valid_structure_values(shape, example_dict, path):
 def _assert_valid_list_values(shape, example_values, path):
     member = shape.member
     for i, value in enumerate(example_values):
-        name = "%s[%s]" % (path[-1], i)
+        name = f"{path[-1]}[{i}]"
         _assert_valid_values(member, value, path[:-1] + [name])
 
 
 def _assert_valid_map_values(shape, example_value, path):
     for key, value in example_value.items():
-        name = '%s["%s"]' % (path[-1], key)
+        name = f'{path[-1]}["{key}"]'
         _assert_valid_values(shape.value, value, path[:-1] + [name])
 
 
@@ -124,8 +132,11 @@ def _assert_valid_timestamp(timestamp, path):
         parse_timestamp(timestamp).timetuple()
     except Exception as e:
         dotted_path = '.'.join(path)
-        raise AssertionError('Failed to parse timestamp %s for %s: %s' % (
-            timestamp, dotted_path, e))
+        raise AssertionError(
+            'Failed to parse timestamp {} for {}: {}'.format(
+                timestamp, dotted_path, e
+            )
+        )
 
 
 def assert_operation_exists(service_model, operation_name):
@@ -133,5 +144,7 @@ def assert_operation_exists(service_model, operation_name):
         service_model.operation_model(operation_name)
     except OperationNotFoundError:
         raise AssertionError(
-            "Examples found in %s for operation %s that does not exist." % (
-                service_model.service_name, operation_name))
+            "Examples found in {} for operation {} that does not exist.".format(
+                service_model.service_name, operation_name
+            )
+        )
